==> mvme-1.14.4-Windows-x64.zip: mvme-1.14.4-Windows-x64/include/mesytec-mvlc/mesytec-mvlc.h <==
/* mesytec-mvlc - driver library for the Mesytec MVLC VME controller
 *
 * Copyright (c) 2020-2023 mesytec GmbH & Co. KG
 *
 * Author: Florian Lüke <f.lueke@mesytec.com>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice, this
 * list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 * this list of conditions and the following disclaimer in the documentation
 * and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
#ifndef __MESYTEC_MVLC_H__
#define __MESYTEC_MVLC_H__

#include "event_builder.h"
#include "git_version.h"
#include "mvlc_blocking_data_api.h"
#include "mvlc_command_builders.h"
#include "mvlc_dialog.h"
#include "mvlc_dialog_util.h"
#include "mvlc_factory.h"
#include "mvlc.h"
#include "mvlc_listfile_gen.h"
#include "mvlc_listfile.h"
#include "mvlc_listfile_util.h"
#include "mvlc_listfile_zip.h"
#ifdef MVLC_HAVE_ZMQ
#include "mvlc_listfile_zmq_ganil.h"
#endif
#include "mvlc_eth_interface.h"
#include "mvlc_readout.h"
#include "mvlc_readout_parser.h"
#include "mvlc_readout_parser_util.h"
#include "mvlc_readout_worker.h"
#include "mvlc_replay.h"
#include "mvlc_stack_executor.h"
#include "mvlc_threading.h"
#include "mvlc_usb_interface.h"
#include "mvlc_util.h"
#include "scanbus_support.h"
#include "util/filesystem.h"
#include "util/fmt.h"
#include "util/int_types.h"
#include "util/io_util.h"
#include "util/logging.h"
#include "util/string_util.h"
#include "vme_constants.h"

#endif /* __MESYTEC_MVLC_H__ */

==> mvme-1.15.2-Windows-x64.zip: mvme-1.15.2-Windows-x64/include/mesytec-mvlc/mesytec-mvlc.h <==
/* mesytec-mvlc - driver library for the Mesytec MVLC VME controller
 *
 * Copyright (c) 2020-2023 mesytec GmbH & Co. KG
 *
 * Author: Florian Lüke <f.lueke@mesytec.com>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice, this
 * list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 * this list of conditions and the following disclaimer in the documentation
 * and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
#ifndef __MESYTEC_MVLC_H__
#define __MESYTEC_MVLC_H__

#include "cpp_compat.h"
#include "event_builder.h"
#include "git_version.h"
#include "mvlc_blocking_data_api.h"
#include "mvlc_command_builders.h"
#include "mvlc_dialog.h"
#include "mvlc_dialog_util.h"
#include "mvlc_factory.h"
#include "mvlc.h"
#include "mvlc_listfile_gen.h"
#include "mvlc_listfile.h"
#include "mvlc_listfile_util.h"
#include "mvlc_listfile_zip.h"
#ifdef MVLC_HAVE_ZMQ
#include "mvlc_listfile_zmq_ganil.h"
#endif
#include "mvlc_eth_interface.h"
#include "mvlc_readout.h"
#include "mvlc_readout_parser.h"
#include "mvlc_readout_parser_util.h"
#include "mvlc_readout_worker.h"
#include "mvlc_replay.h"
#include "mvlc_stack_executor.h"
#include "mvlc_threading.h"
#include "mvlc_usb_interface.h"
#include "mvlc_util.h"
#include "scanbus_support.h"
#include "util/algo.h"
#include "util/counters.h"
#include "util/filesystem.h"
#include "util/fmt.h"
#include "util/int_types.h"
#include "util/io_util.h"
#include "util/logging.h"
#include "util/signal_handling.h"
#include "util/stopwatch.h"
#include "util/string_util.h"
#include "vme_constants.h"

#endif /* __MESYTEC_MVLC_H__ */
